#ifndef _CAMMENU
#define _CAMMENU

/* ************************************************************************** */
/* Includes definitions                                                       */
/* ************************************************************************** */
//#define __mdebug printf("%s:%d\n", __FILE__, __LINE__)
#include <cstdio>					// fgets, fopen, perror, printf, sprintf
#include <string>					// string class
#include <vector>					// vector class
#include "./libUtilsVar.h"		// Utils library (uses util::format)
#include <cv.h>					// includes OpenCV definitions
#include <highgui.h>				// includes highGUI definitions
#include "menuTreeGUI.h"		// class that represents graphically menu tree


		
class DetectarObjetos
{
private:
	cv::Size imgSize;										/** Tamaño de la imagen a mostrar */
	static const int _MENULEFTWIDTH = 130;			/** Tamaño por defecto del menu lateral */
	static const int _MENUBOTTOMHEIGHT = 35;		/** Tamaño por defecto de menu inferior */
	cv::VideoCapture streamCapture;/** flujo de captura de la camara */
	cv::Mat menuImg;										/** imagen que contiene la imagen mostrada y el menu de usuario */
	cv::Mat showImg;										/** imagen mostrada */
	cv::Mat frame;											/** Imagen capturada de la camara (no se debe procesar directamente) */
	cv::Mat imgParaComparar;							/** Imagen de fondo para detectar movimiento */
	cv::Rect selectColorArea;							/** Area que se utilizara para seleccionar el color a detectar */
	cv::Scalar colorObjeto;								/** Color a detectar */
	cv::Scalar colorObjetoDev;							/** Variacion del color a detectar */
	MenuTreeGUI menutreegui;							/** Clase que muestra un menu grafico al usuario */
	char key;												/** tecla pulsada por el usuario */
	int salir;												/** true cuando se pulse salir en el menu */
	std::string operacion;								/** Indica la operacion a realizar sobre la imagen */
	
public:	
	
	/** Constructor */
	DetectarObjetos();

	/**
	 * Abre la camara indicada
	 */
	int abrirCamara(int ncam);
	
	/**
	 * Actualiza el interfaz grafico
	 */
	int update(int wait = 50);
	
	/**
	 * Devuelve verdadero si se ha seleccionado salir en el menu
	 */
	int Exit();
	
private:
	
	/**
	 * Inicializa el menu de usuario
	 */
	void initMenu();

	/**
	 * Llama a los submenus para realizar operaciones sobre la imagen segun la eleccion del usuario
	 */
	void ejecutarOperacion();
	
	/**
	 * Ejecuta las operaciones correspondientes al menu de deteccion de objetos por color
	 */
	void menuDetectarColor();
	
	/**
	 * Ejecuta las operaciones correspondientes al menu de deteccion de objetos por movimiento
	 */
	void menuDetectarMovimiento();
	
	/**
	 * Lee la entrada de menu seleccionada por el usuario
	 */
	void leeEntradaDeUsuario();
};

#endif
